==> dpp-runner-0.0.1.tar.gz: dpp-runner-0.0.1/dpp_runner/lib.py <==
import threading
import concurrent.futures
import tempfile
import logging
import uuid
import os

from datapackage_pipelines.manager import ProgressReport, run_pipelines

class DppRunner:

    def __init__(self):
        self.running = {}
        self.rlock = threading.RLock()
        self.pool = concurrent.futures.ThreadPoolExecutor(max_workers=8)


    def _run_in_background(self, uid, dirname, status_cb=None):
        def progress_cb(pr: ProgressReport):
            logging.info('GOT CALLBACK')
            with self.rlock:
                pipeline_id, row_count, success = pr
                current = self.running[uid]['progress'].get(pipeline_id)
                self.running[uid]['progress'].update({
                    pipeline_id: dict(
                        done=success is not None,
                        success=success,
                        rows=row_count
                    )
                })
                if status_cb:
                    if current is None:
                        status_cb(pipeline_id, 'INPROGRESS')
                    else:
                        if success is not None:
                            status_cb(pipeline_id, 'SUCCESS' if success else 'FAILED')


        logging.info('Running %s in background', uid)
        try:
            results = run_pipelines('all',
                                    dirname, 
                                    use_cache=False, 
                                    dirty=False, 
                                    force=False, 
                                    concurrency=999,
                                    verbose_logs=True,
                                    progress_cb=progress_cb)
            logging.info('Done!')
            with self.rlock:
                self.running[uid]['results'] = [
                    p._asdict()
                    for p in results
                ]
                del self.running[uid]['dir']
        except Exception as e:
            logging.exception('Failed to run pipelines')


    def start(self, kind, data, status_cb=None):
        if kind is None:
            filename = 'pipeline-spec.yaml'
        else:
            filename = kind + '.source-spec.yaml'

        tempdir = tempfile.TemporaryDirectory()
        with open(os.path.join(tempdir.name, filename), 'wb') as spec:
            spec.write(data)

        uid = uuid.uuid4().hex

        self.running[uid] = dict(
            dir=tempdir,
            results={},
            progress={}
        )
        self.pool.submit(self._run_in_background, uid, tempdir.name, status_cb)
        
        return uid


    def status(self, uid):
        with self.rlock:
            ret = self.running.get(uid, {})
            ret = dict(
                results=ret.get('results'),
                progress=ret.get('progress')
            )
            return ret

==> dpp-runner-0.0.5.tar.gz: dpp-runner-0.0.5/dpp_runner/lib.py <==
import threading
import concurrent.futures
import tempfile
import logging
import uuid
import os

from datapackage_pipelines.manager import ProgressReport, run_pipelines

class DppRunner:

    def __init__(self):
        self.running = {}
        self.rlock = threading.RLock()
        self.pool = concurrent.futures.ThreadPoolExecutor(max_workers=8)


    def _run_in_background(self, uid, dirname, verbosity=False, status_cb=None):
        def progress_cb(pr: ProgressReport):
            with self.rlock:
                pipeline_id, row_count, success, errors, stats = pr
                if verbosity:
                    logging.info('Callback %s #%d (success: %s, errors: %r, stats: %s)',
                                 pipeline_id, row_count, success, errors,stats)
                current = self.running[uid]['progress'].get(pipeline_id)
                self.running[uid]['progress'].update({
                    pipeline_id: dict(
                        done=success is not None,
                        success=success,
                        rows=row_count,
                        errors=errors,
                        stats=stats
                    )
                })
                if status_cb:
                    if current is None:
                        status_cb(pipeline_id, 'INPROGRESS')
                    else:
                        if success is not None:
                            status_cb(pipeline_id, 
                                      'SUCCESS' if success else 'FAILED',
                                      errors=errors, stats=stats)

        try:
            if verbosity:
                logging.info('Running all pipelines')
            results = run_pipelines('all',
                                    dirname, 
                                    use_cache=False, 
                                    dirty=False, 
                                    force=False, 
                                    concurrency=999,
                                    verbose_logs=verbosity,
                                    progress_cb=progress_cb)
            if verbosity:
                logging.info('Running complete')
            with self.rlock:
                self.running[uid]['results'] = [
                    p._asdict()
                    for p in results
                ]
                if verbosity:
                    logging.info('Results %r', self.running[uid])
                del self.running[uid]['dir']
        except Exception as e:
            logging.exception('Failed to run pipelines')


    def start(self, kind, data, verbosity=False, status_cb=None):
        if kind is None:
            filename = 'pipeline-spec.yaml'
        else:
            filename = kind + '.source-spec.yaml'

        tempdir = tempfile.TemporaryDirectory()
        with open(os.path.join(tempdir.name, filename), 'wb') as spec:
            spec.write(data)

        uid = uuid.uuid4().hex

        self.running[uid] = dict(
            dir=tempdir,
            results={},
            progress={}
        )
        self.pool.submit(self._run_in_background, uid, tempdir.name, verbosity, status_cb)
        
        return uid


    def status(self, uid):
        with self.rlock:
            ret = self.running.get(uid, {})
            ret = dict(
                results=ret.get('results'),
                progress=ret.get('progress')
            )
            return ret
